==> jc-sunart-domain-0.0.4-sources.jar: com/xforceplus/ultraman/app/jcsunart/metadata/EntityMeta.java <==
package com.xforceplus.ultraman.app.jcsunart.metadata;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import com.xforceplus.ultraman.bocp.gen.typed.TypedField;


/**
* <p>
    * 
    * </p>
*
* @author ultraman
* @since 2022-02-21
*/

public class EntityMeta {

    public interface OqsengineSdkOmAuditLog {
        static Long id() {
            return 1484048072896225281L;
        }
        static String code() {
            return "oqsengineSdkOmAuditLog";
        }
        TypedField<Long> OPERATOR_ID = new TypedField<>(Long.class, "operator_id");
        TypedField<String> OPERATOR_CODE = new TypedField<>(String.class, "operator_code");
        TypedField<String> OPERATOR_NAME = new TypedField<>(String.class, "operator_name");
        TypedField<String> OPERATE_TYPE = new TypedField<>(String.class, "operate_type");
        TypedField<LocalDateTime> OPERATE_TIME = new TypedField<>(LocalDateTime.class, "operate_time");
        TypedField<Long> APP_ID = new TypedField<>(Long.class, "app_id");
        TypedField<String> APP_CODE = new TypedField<>(String.class, "app_code");
        TypedField<Long> BO_ID = new TypedField<>(Long.class, "bo_id");
        TypedField<String> BO_CODE = new TypedField<>(String.class, "bo_code");
        TypedField<String> BO_NAME = new TypedField<>(String.class, "bo_name");
        TypedField<Long> ENTITY_ID = new TypedField<>(Long.class, "entity_id");
        TypedField<String> REQUEST_DATA = new TypedField<>(String.class, "request_data");
        TypedField<String> RESPONSE_DATA = new TypedField<>(String.class, "response_data");
        TypedField<String> REMARK = new TypedField<>(String.class, "remark");
        TypedField<Long> ID = new TypedField<>(Long.class, "id");
        TypedField<Long> TENANT_ID = new TypedField<>(Long.class, "tenant_id");
        TypedField<String> TENANT_CODE = new TypedField<>(String.class, "tenant_code");
        TypedField<LocalDateTime> CREATE_TIME = new TypedField<>(LocalDateTime.class, "create_time");
        TypedField<LocalDateTime> UPDATE_TIME = new TypedField<>(LocalDateTime.class, "update_time");
        TypedField<Long> CREATE_USER_ID = new TypedField<>(Long.class, "create_user_id");
        TypedField<Long> UPDATE_USER_ID = new TypedField<>(Long.class, "update_user_id");
        TypedField<String> CREATE_USER_NAME = new TypedField<>(String.class, "create_user_name");
        TypedField<String> UPDATE_USER_NAME = new TypedField<>(String.class, "update_user_name");
        TypedField<String> DELETE_FLAG = new TypedField<>(String.class, "delete_flag");
    }

    public interface InvoiceReceipt {
        static Long id() {
            return 1484064499082534913L;
        }
        static String code() {
            return "invoiceReceipt";
        }
        TypedField<String> BUSINESS_TYPE = new TypedField<>(String.class, "business_type");
        TypedField<String> SERIAL_NO = new TypedField<>(String.class, "serial_no");
        TypedField<String> TICKET_DEPT = new TypedField<>(String.class, "ticket_dept");
        TypedField<String> BUSINESS_NO = new TypedField<>(String.class, "business_no");
        TypedField<String> INVOICE_TYPE = new TypedField<>(String.class, "invoice_type");
        TypedField<String> INVOICE_NUMBER = new TypedField<>(String.class, "invoice_number");
        TypedField<String> BATCH_NO = new TypedField<>(String.class, "batch_no");
        TypedField<String> REMARK = new TypedField<>(String.class, "remark");
        TypedField<String> EXT1 = new TypedField<>(String.class, "ext1");
        TypedField<String> EXT2 = new TypedField<>(String.class, "ext2");
        TypedField<String> EXT3 = new TypedField<>(String.class, "ext3");
        TypedField<String> EXT4 = new TypedField<>(String.class, "ext4");
        TypedField<String> EXT5 = new TypedField<>(String.class, "ext5");
        TypedField<LocalDateTime> RECEIPT_DATE = new TypedField<>(LocalDateTime.class, "receipt_date");
        TypedField<String> INPUT_USER = new TypedField<>(String.class, "input_user");
        TypedField<Long> ID = new TypedField<>(Long.class, "id");
        TypedField<Long> TENANT_ID = new TypedField<>(Long.class, "tenant_id");
        TypedField<String> TENANT_CODE = new TypedField<>(String.class, "tenant_code");
        TypedField<LocalDateTime> CREATE_TIME = new TypedField<>(LocalDateTime.class, "create_time");
        TypedField<LocalDateTime> UPDATE_TIME = new TypedField<>(LocalDateTime.class, "update_time");
        TypedField<Long> CREATE_USER_ID = new TypedField<>(Long.class, "create_user_id");
        TypedField<Long> UPDATE_USER_ID = new TypedField<>(Long.class, "update_user_id");
        TypedField<String> CREATE_USER_NAME = new TypedField<>(String.class, "create_user_name");
        TypedField<String> UPDATE_USER_NAME = new TypedField<>(String.class, "update_user_name");
        TypedField<String> DELETE_FLAG = new TypedField<>(String.class, "delete_flag");
        TypedField<String> STATUS = new TypedField<>(String.class, "status");
        TypedField<LocalDateTime> DELETE_TIME = new TypedField<>(LocalDateTime.class, "delete_time");
    }

    public interface InvoiceDto {
        static Long id() {
            return 1484069322125287426L;
        }
        static String code() {
            return "invoiceDto";
        }
        TypedField<String> SERIAL_NO = new TypedField<>(String.class, "serial_no");
        TypedField<LocalDateTime> SCAN_TIME = new TypedField<>(LocalDateTime.class, "scan_time");
        TypedField<String> ACCOUNT_NO = new TypedField<>(String.class, "account_no");
        TypedField<String> INVOICE_CODE = new TypedField<>(String.class, "invoice_code");
        TypedField<String> INVOICE_NO = new TypedField<>(String.class, "invoice_no");
        TypedField<String> AMOUNT_WITHOUT_TAX = new TypedField<>(String.class, "amount_without_tax");
        TypedField<String> TAX_AMOUNT = new TypedField<>(String.class, "tax_amount");
        TypedField<LocalDateTime> PAPER_DRAW_DATE = new TypedField<>(LocalDateTime.class, "paper_draw_date");
        TypedField<String> INVOICE_TYPE = new TypedField<>(String.class, "invoice_type");
        TypedField<String> SELLER_TAX_NO = new TypedField<>(String.class, "seller_tax_no");
        TypedField<String> SELLER_NAME = new TypedField<>(String.class, "seller_name");
        TypedField<LocalDateTime> PROCESS_TIME = new TypedField<>(LocalDateTime.class, "process_time");
        TypedField<String> REMARK = new TypedField<>(String.class, "remark");
        TypedField<LocalDateTime> REFUND_TIME = new TypedField<>(LocalDateTime.class, "refund_time");
        TypedField<String> REFUND_REASON = new TypedField<>(String.class, "refund_reason");
        TypedField<String> REFUND_TYPE = new TypedField<>(String.class, "refund_type");
        TypedField<String> COURIER_NUMBER = new TypedField<>(String.class, "courier_number");
        TypedField<String> PROCESS_USER = new TypedField<>(String.class, "process_user");
        TypedField<String> ENTER_USER = new TypedField<>(String.class, "enter_user");
        TypedField<Long> ID = new TypedField<>(Long.class, "id");
        TypedField<Long> TENANT_ID = new TypedField<>(Long.class, "tenant_id");
        TypedField<String> TENANT_CODE = new TypedField<>(String.class, "tenant_code");
        TypedField<LocalDateTime> CREATE_TIME = new TypedField<>(LocalDateTime.class, "create_time");
        TypedField<LocalDateTime> UPDATE_TIME = new TypedField<>(LocalDateTime.class, "update_time");
        TypedField<Long> CREATE_USER_ID = new TypedField<>(Long.class, "create_user_id");
        TypedField<Long> UPDATE_USER_ID = new TypedField<>(Long.class, "update_user_id");
        TypedField<String> CREATE_USER_NAME = new TypedField<>(String.class, "create_user_name");
        TypedField<String> UPDATE_USER_NAME = new TypedField<>(String.class, "update_user_name");
        TypedField<String> DELETE_FLAG = new TypedField<>(String.class, "delete_flag");
        TypedField<String> CHECK_STATUS = new TypedField<>(String.class, "check_status");
        TypedField<String> INVOICE_ID = new TypedField<>(String.class, "invoice_id");
    }

}

==> jc-sunart-domain-0.0.71-sources.jar: com/xforceplus/ultraman/app/jcsunart/metadata/EntityMeta.java <==
package com.xforceplus.ultraman.app.jcsunart.metadata;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import com.xforceplus.ultraman.bocp.gen.typed.TypedField;


/**
* <p>
    * 
    * </p>
*
* @author ultraman
* @since 2022-08-04
*/

public class EntityMeta {

    public interface OqsengineSdkOmAuditLog {
        static Long id() {
            return 1484048072896225281L;
        }
        static String code() {
            return "oqsengineSdkOmAuditLog";
        }
        TypedField<Long> OPERATOR_ID = new TypedField<>(Long.class, "operator_id");
        TypedField<String> OPERATOR_CODE = new TypedField<>(String.class, "operator_code");
        TypedField<String> OPERATOR_NAME = new TypedField<>(String.class, "operator_name");
        TypedField<String> OPERATE_TYPE = new TypedField<>(String.class, "operate_type");
        TypedField<LocalDateTime> OPERATE_TIME = new TypedField<>(LocalDateTime.class, "operate_time");
        TypedField<Long> APP_ID = new TypedField<>(Long.class, "app_id");
        TypedField<String> APP_CODE = new TypedField<>(String.class, "app_code");
        TypedField<Long> BO_ID = new TypedField<>(Long.class, "bo_id");
        TypedField<String> BO_CODE = new TypedField<>(String.class, "bo_code");
        TypedField<String> BO_NAME = new TypedField<>(String.class, "bo_name");
        TypedField<Long> ENTITY_ID = new TypedField<>(Long.class, "entity_id");
        TypedField<String> REQUEST_DATA = new TypedField<>(String.class, "request_data");
        TypedField<String> RESPONSE_DATA = new TypedField<>(String.class, "response_data");
        TypedField<String> REMARK = new TypedField<>(String.class, "remark");
        TypedField<Long> ID = new TypedField<>(Long.class, "id");
        TypedField<Long> TENANT_ID = new TypedField<>(Long.class, "tenant_id");
        TypedField<String> TENANT_CODE = new TypedField<>(String.class, "tenant_code");
        TypedField<LocalDateTime> CREATE_TIME = new TypedField<>(LocalDateTime.class, "create_time");
        TypedField<LocalDateTime> UPDATE_TIME = new TypedField<>(LocalDateTime.class, "update_time");
        TypedField<Long> CREATE_USER_ID = new TypedField<>(Long.class, "create_user_id");
        TypedField<Long> UPDATE_USER_ID = new TypedField<>(Long.class, "update_user_id");
        TypedField<String> CREATE_USER_NAME = new TypedField<>(String.class, "create_user_name");
        TypedField<String> UPDATE_USER_NAME = new TypedField<>(String.class, "update_user_name");
        TypedField<String> DELETE_FLAG = new TypedField<>(String.class, "delete_flag");
    }

    public interface InvoiceReceipt {
        static Long id() {
            return 1484064499082534913L;
        }
        static String code() {
            return "invoiceReceipt";
        }
        TypedField<String> BUSINESS_TYPE = new TypedField<>(String.class, "business_type");
        TypedField<String> SERIAL_NO = new TypedField<>(String.class, "serial_no");
        TypedField<String> TICKET_DEPT = new TypedField<>(String.class, "ticket_dept");
        TypedField<String> BUSINESS_NO = new TypedField<>(String.class, "business_no");
        TypedField<String> INVOICE_TYPE = new TypedField<>(String.class, "invoice_type");
        TypedField<String> BATCH_NO = new TypedField<>(String.class, "batch_no");
        TypedField<String> REMARK = new TypedField<>(String.class, "remark");
        TypedField<String> EXT1 = new TypedField<>(String.class, "ext1");
        TypedField<String> EXT2 = new TypedField<>(String.class, "ext2");
        TypedField<String> EXT3 = new TypedField<>(String.class, "ext3");
        TypedField<String> EXT4 = new TypedField<>(String.class, "ext4");
        TypedField<String> EXT5 = new TypedField<>(String.class, "ext5");
        TypedField<LocalDateTime> RECEIPT_DATE = new TypedField<>(LocalDateTime.class, "receipt_date");
        TypedField<String> INPUT_USER = new TypedField<>(String.class, "input_user");
        TypedField<Long> ID = new TypedField<>(Long.class, "id");
        TypedField<Long> TENANT_ID = new TypedField<>(Long.class, "tenant_id");
        TypedField<String> TENANT_CODE = new TypedField<>(String.class, "tenant_code");
        TypedField<LocalDateTime> CREATE_TIME = new TypedField<>(LocalDateTime.class, "create_time");
        TypedField<LocalDateTime> UPDATE_TIME = new TypedField<>(LocalDateTime.class, "update_time");
        TypedField<Long> CREATE_USER_ID = new TypedField<>(Long.class, "create_user_id");
        TypedField<Long> UPDATE_USER_ID = new TypedField<>(Long.class, "update_user_id");
        TypedField<String> CREATE_USER_NAME = new TypedField<>(String.class, "create_user_name");
        TypedField<String> UPDATE_USER_NAME = new TypedField<>(String.class, "update_user_name");
        TypedField<String> DELETE_FLAG = new TypedField<>(String.class, "delete_flag");
        TypedField<String> STATUS = new TypedField<>(String.class, "status");
        TypedField<LocalDateTime> DELETE_TIME = new TypedField<>(LocalDateTime.class, "delete_time");
        TypedField<Long> INVOICE_NUMBER = new TypedField<>(Long.class, "invoice_number");
        TypedField<String> RECEIPT_TIME = new TypedField<>(String.class, "receipt_time");
        TypedField<String> REGION = new TypedField<>(String.class, "region");
    }

    public interface InvoiceDto {
        static Long id() {
            return 1484069322125287426L;
        }
        static String code() {
            return "invoiceDto";
        }
        TypedField<String> SERIAL_NO = new TypedField<>(String.class, "serial_no");
        TypedField<LocalDateTime> SCAN_TIME = new TypedField<>(LocalDateTime.class, "scan_time");
        TypedField<String> ACCOUNT_NO = new TypedField<>(String.class, "account_no");
        TypedField<String> INVOICE_CODE = new TypedField<>(String.class, "invoice_code");
        TypedField<String> INVOICE_NO = new TypedField<>(String.class, "invoice_no");
        TypedField<BigDecimal> AMOUNT_WITHOUT_TAX = new TypedField<>(BigDecimal.class, "amount_without_tax");
        TypedField<BigDecimal> TAX_AMOUNT = new TypedField<>(BigDecimal.class, "tax_amount");
        TypedField<LocalDateTime> PAPER_DRAW_DATE = new TypedField<>(LocalDateTime.class, "paper_draw_date");
        TypedField<String> INVOICE_TYPE = new TypedField<>(String.class, "invoice_type");
        TypedField<String> SELLER_TAX_NO = new TypedField<>(String.class, "seller_tax_no");
        TypedField<String> SELLER_NAME = new TypedField<>(String.class, "seller_name");
        TypedField<LocalDateTime> PROCESS_TIME = new TypedField<>(LocalDateTime.class, "process_time");
        TypedField<String> REMARK = new TypedField<>(String.class, "remark");
        TypedField<LocalDateTime> REFUND_TIME = new TypedField<>(LocalDateTime.class, "refund_time");
        TypedField<String> REFUND_TYPE = new TypedField<>(String.class, "refund_type");
        TypedField<String> COURIER_NUMBER = new TypedField<>(String.class, "courier_number");
        TypedField<String> PROCESS_USER = new TypedField<>(String.class, "process_user");
        TypedField<String> ENTER_USER = new TypedField<>(String.class, "enter_user");
        TypedField<Long> ID = new TypedField<>(Long.class, "id");
        TypedField<Long> TENANT_ID = new TypedField<>(Long.class, "tenant_id");
        TypedField<String> TENANT_CODE = new TypedField<>(String.class, "tenant_code");
        TypedField<LocalDateTime> CREATE_TIME = new TypedField<>(LocalDateTime.class, "create_time");
        TypedField<LocalDateTime> UPDATE_TIME = new TypedField<>(LocalDateTime.class, "update_time");
        TypedField<Long> CREATE_USER_ID = new TypedField<>(Long.class, "create_user_id");
        TypedField<Long> UPDATE_USER_ID = new TypedField<>(Long.class, "update_user_id");
        TypedField<String> CREATE_USER_NAME = new TypedField<>(String.class, "create_user_name");
        TypedField<String> UPDATE_USER_NAME = new TypedField<>(String.class, "update_user_name");
        TypedField<String> DELETE_FLAG = new TypedField<>(String.class, "delete_flag");
        TypedField<String> CHECK_STATUS = new TypedField<>(String.class, "check_status");
        TypedField<String> INVOICE_ID = new TypedField<>(String.class, "invoice_id");
        TypedField<String> ENTER_USERNAME = new TypedField<>(String.class, "enter_username");
        TypedField<String> REFUND_REASON = new TypedField<>(String.class, "refund_reason");
        TypedField<String> REFUND_DATE = new TypedField<>(String.class, "refund_date");
        TypedField<String> BUSINESS_TYPE = new TypedField<>(String.class, "business_type");
        TypedField<String> DEPARTMENT = new TypedField<>(String.class, "department");
        TypedField<String> INPUT_BY = new TypedField<>(String.class, "input_by");
        TypedField<String> PURCHASE_NUMBER = new TypedField<>(String.class, "purchase_number");
        TypedField<String> SUPPLY_INVOICE_NO = new TypedField<>(String.class, "supply_invoice_No");
        TypedField<String> FACTORY_FIELD = new TypedField<>(String.class, "factory_field");
        TypedField<String> REGION = new TypedField<>(String.class, "region");
    }

    public interface InvoiceRefundReport {
        static Long id() {
            return 1504643861913501697L;
        }
        static String code() {
            return "invoiceRefundReport";
        }
        TypedField<LocalDateTime> DATE = new TypedField<>(LocalDateTime.class, "date");
        TypedField<Long> SC_ZZ = new TypedField<>(Long.class, "sc_zz");
        TypedField<Long> SC_ZP = new TypedField<>(Long.class, "sc_zp");
        TypedField<Long> SC_OTHER = new TypedField<>(Long.class, "sc_other");
        TypedField<Long> ID = new TypedField<>(Long.class, "id");
        TypedField<Long> TENANT_ID = new TypedField<>(Long.class, "tenant_id");
        TypedField<String> TENANT_CODE = new TypedField<>(String.class, "tenant_code");
        TypedField<LocalDateTime> CREATE_TIME = new TypedField<>(LocalDateTime.class, "create_time");
        TypedField<LocalDateTime> UPDATE_TIME = new TypedField<>(LocalDateTime.class, "update_time");
        TypedField<Long> CREATE_USER_ID = new TypedField<>(Long.class, "create_user_id");
        TypedField<Long> UPDATE_USER_ID = new TypedField<>(Long.class, "update_user_id");
        TypedField<String> CREATE_USER_NAME = new TypedField<>(String.class, "create_user_name");
        TypedField<String> UPDATE_USER_NAME = new TypedField<>(String.class, "update_user_name");
        TypedField<String> DELETE_FLAG = new TypedField<>(String.class, "delete_flag");
        TypedField<Long> SC_DKL = new TypedField<>(Long.class, "sc_dkl");
        TypedField<Long> FSC_ZZ = new TypedField<>(Long.class, "fsc_zz");
        TypedField<Long> FSC_ZP = new TypedField<>(Long.class, "fsc_zp");
        TypedField<Long> FSC_DKL = new TypedField<>(Long.class, "fsc_dkl");
        TypedField<Long> FSC_TXF = new TypedField<>(Long.class, "fsc_txf");
        TypedField<Long> FSC_QT = new TypedField<>(Long.class, "fsc_qt");
        TypedField<Long> INVOICE_REFUND = new TypedField<>(Long.class, "invoice_refund");
        TypedField<Long> TOTAL = new TypedField<>(Long.class, "total");
        TypedField<String> TIME = new TypedField<>(String.class, "time");
        TypedField<String> REGION = new TypedField<>(String.class, "region");
    }

    public interface InvoiceReceiptRecord {
        static Long id() {
            return 1518846869463441409L;
        }
        static String code() {
            return "invoiceReceiptRecord";
        }
        TypedField<String> BUSINESS_TYPE = new TypedField<>(String.class, "business_type");
        TypedField<String> TICKET_DEPT = new TypedField<>(String.class, "ticket_dept");
        TypedField<String> BUSINESS_NO = new TypedField<>(String.class, "business_no");
        TypedField<String> INVOICE_TYPE = new TypedField<>(String.class, "invoice_type");
        TypedField<String> BATCH_NO = new TypedField<>(String.class, "batch_no");
        TypedField<LocalDateTime> RECEIPT_DATE = new TypedField<>(LocalDateTime.class, "receipt_date");
        TypedField<String> INPUT_USER = new TypedField<>(String.class, "input_user");
        TypedField<String> STATUS = new TypedField<>(String.class, "status");
        TypedField<LocalDateTime> DELETE_TIME = new TypedField<>(LocalDateTime.class, "delete_time");
        TypedField<Long> INVOICE_NUMBER = new TypedField<>(Long.class, "invoice_number");
        TypedField<String> RECEIPT_TIME = new TypedField<>(String.class, "receipt_time");
        TypedField<Long> ID = new TypedField<>(Long.class, "id");
        TypedField<Long> TENANT_ID = new TypedField<>(Long.class, "tenant_id");
        TypedField<String> TENANT_CODE = new TypedField<>(String.class, "tenant_code");
        TypedField<LocalDateTime> CREATE_TIME = new TypedField<>(LocalDateTime.class, "create_time");
        TypedField<LocalDateTime> UPDATE_TIME = new TypedField<>(LocalDateTime.class, "update_time");
        TypedField<Long> CREATE_USER_ID = new TypedField<>(Long.class, "create_user_id");
        TypedField<Long> UPDATE_USER_ID = new TypedField<>(Long.class, "update_user_id");
        TypedField<String> CREATE_USER_NAME = new TypedField<>(String.class, "create_user_name");
        TypedField<String> UPDATE_USER_NAME = new TypedField<>(String.class, "update_user_name");
        TypedField<String> DELETE_FLAG = new TypedField<>(String.class, "delete_flag");
        TypedField<LocalDateTime> SEND_TIME = new TypedField<>(LocalDateTime.class, "send_time");
        TypedField<String> SEND_STATUS = new TypedField<>(String.class, "send_status");
        TypedField<String> SEND_NUMBER = new TypedField<>(String.class, "send_number");
    }

    public interface InvoiceRefundRecord {
        static Long id() {
            return 1518848862705754114L;
        }
        static String code() {
            return "invoiceRefundRecord";
        }
        TypedField<LocalDateTime> SCAN_TIME = new TypedField<>(LocalDateTime.class, "scan_time");
        TypedField<String> ACCOUNT_NO = new TypedField<>(String.class, "account_no");
        TypedField<String> INVOICE_CODE = new TypedField<>(String.class, "invoice_code");
        TypedField<String> INVOICE_NO = new TypedField<>(String.class, "invoice_no");
        TypedField<BigDecimal> AMOUNT_WITHOUT_TAX = new TypedField<>(BigDecimal.class, "amount_without_tax");
        TypedField<BigDecimal> TAX_AMOUNT = new TypedField<>(BigDecimal.class, "tax_amount");
        TypedField<LocalDateTime> PAPER_DRAW_DATE = new TypedField<>(LocalDateTime.class, "paper_draw_date");
        TypedField<String> INVOICE_TYPE = new TypedField<>(String.class, "invoice_type");
        TypedField<String> SELLER_TAX_NO = new TypedField<>(String.class, "seller_tax_no");
        TypedField<String> SELLER_NAME = new TypedField<>(String.class, "seller_name");
        TypedField<LocalDateTime> PROCESS_TIME = new TypedField<>(LocalDateTime.class, "process_time");
        TypedField<String> REMARK = new TypedField<>(String.class, "remark");
        TypedField<LocalDateTime> REFUND_TIME = new TypedField<>(LocalDateTime.class, "refund_time");
        TypedField<String> REFUND_TYPE = new TypedField<>(String.class, "refund_type");
        TypedField<String> COURIER_NUMBER = new TypedField<>(String.class, "courier_number");
        TypedField<String> PROCESS_USER = new TypedField<>(String.class, "process_user");
        TypedField<String> ENTER_USER = new TypedField<>(String.class, "enter_user");
        TypedField<String> CHECK_STATUS = new TypedField<>(String.class, "check_status");
        TypedField<String> INVOICE_ID = new TypedField<>(String.class, "invoice_id");
        TypedField<String> ENTER_USERNAME = new TypedField<>(String.class, "enter_username");
        TypedField<String> REFUND_REASON = new TypedField<>(String.class, "refund_reason");
        TypedField<String> REFUND_DATE = new TypedField<>(String.class, "refund_date");
        TypedField<String> SEND_STATUS = new TypedField<>(String.class, "send_status");
        TypedField<LocalDateTime> SEND_TIME = new TypedField<>(LocalDateTime.class, "send_time");
        TypedField<String> SEND_NUMBER = new TypedField<>(String.class, "send_number");
        TypedField<Long> ID = new TypedField<>(Long.class, "id");
        TypedField<Long> TENANT_ID = new TypedField<>(Long.class, "tenant_id");
        TypedField<String> TENANT_CODE = new TypedField<>(String.class, "tenant_code");
        TypedField<LocalDateTime> CREATE_TIME = new TypedField<>(LocalDateTime.class, "create_time");
        TypedField<LocalDateTime> UPDATE_TIME = new TypedField<>(LocalDateTime.class, "update_time");
        TypedField<Long> CREATE_USER_ID = new TypedField<>(Long.class, "create_user_id");
        TypedField<Long> UPDATE_USER_ID = new TypedField<>(Long.class, "update_user_id");
        TypedField<String> CREATE_USER_NAME = new TypedField<>(String.class, "create_user_name");
        TypedField<String> UPDATE_USER_NAME = new TypedField<>(String.class, "update_user_name");
        TypedField<String> DELETE_FLAG = new TypedField<>(String.class, "delete_flag");
    }

}
